import { File } from 'formidable';
import { IncomingHttpHeaders } from 'http';
import { Middleware } from 'koa';
import { HttpMethodEnum } from 'koa-body';
/**
 * Supported signature types.
 */
export declare const SignatureType: readonly ["event"];
/**
 * Union type of all valid function SignatureType values.
 */
export type SignatureType = (typeof SignatureType)[number];
export type methodType = keyof typeof HttpMethodEnum | 'TRACE';
export interface httpBasis {
    url: string;
    httpMethod: methodType;
    headers: IncomingHttpHeaders;
}
export type eventType = 'http' | 'websocket.upgrade' | 'websocket.connection';
/**
 * TCBContext TCB 调用上下文，由 HTTP 请求头注入
 */
export interface TCBContext extends Record<string, unknown> {
}
/**
 * WeChatContext 微信调用上下文，由 HTTP 请求头注入
 */
export interface WeChatContext extends Record<string, unknown> {
}
/**
 * State 请求中所传递的业务相关信息
 */
export interface State {
    eventID: string;
    eventType: eventType;
    timestamp: string;
    tcbContext?: TCBContext;
    wechatContext?: WeChatContext;
    event?: unknown;
    context?: ContextInjected;
}
/**
 * ErrorResult 包含错误的 Result
 */
export type ErrorResult = {
    code: string;
    message: string;
};
/**
 * IExtendedState 扩展的请求状态信息
 */
export interface IExtendedState extends State {
    /**
     * 是否超时
     */
    isTimeout?: boolean;
    /**
     * 用户代码抛出的错误
     */
    error?: Error;
    errorResult?: ErrorResult;
    /**
     * 用户代码耗时
     */
    userTimeCost?: number;
}
/**
 * 请求中传递的 HTTP 相关上下文
 */
export interface HTTPContext {
    httpContext?: httpBasis;
}
export interface SseEvent<T = string | Record<string, unknown>> {
    data: T;
    comment?: string;
    event?: string;
    id?: string;
    retry?: number;
}
export interface ISeverSentEvent {
    setEncoder(encoder: TextEncoder): void;
    send(event: SseEvent): boolean;
}
export interface IWebSocket {
    send(buf: Buffer): void;
    close(code?: number, reason?: string): void;
}
export interface ContextInjected extends State, HTTPContext {
    sse?(): ISeverSentEvent | null;
    ws?: IWebSocket | null;
}
/**
 * IExtendedContext 扩展的请求上下文
 */
export interface IExtendedContext extends HTTPContext {
    rawBody?: Buffer;
}
export type KoaMiddleware = Middleware<IExtendedState, IExtendedContext>;
export type FormEvent = {
    [file: string]: File | File[] | string;
};
export interface IntegrationResponse {
    statusCode: number;
    headers: {
        [key: string]: string | string[];
    };
    body: unknown;
}
export type HandleUpgradeResult = {
    allowWebSocket?: boolean;
    statusCode?: number;
    body?: string;
    contentType?: string;
};
export interface EventFunction {
    (event: unknown, context: ContextInjected): IntegrationResponse | unknown;
    handleUpgrade?(context: ContextInjected): Promise<HandleUpgradeResult>;
}
export type HandlerFunction = EventFunction;
export declare enum LogType {
    ACCESSLOG = "accesslog",
    USERCODELOG = "usercodelog"
}
export interface ILog {
    '@timestamp': string;
    logType: LogType;
}
export interface IUserCodeLogItem {
    '@timestamp'?: string;
    caller?: string;
    stacktraces?: string;
    level?: string;
    content: string | Uint8Array;
}
export interface IUserCodeLog {
    '@timestamp': string;
    logType: LogType;
    eventId: string;
    scene?: 'logBeforeReturn' | 'logAfterReturn';
    logs: IUserCodeLogItem[];
}
//# sourceMappingURL=types.d.ts.map